@@ -30,7 +30,7 @@ NULL
 #'@param symnum.args a list of arguments to pass to the function
 #'  \code{\link[stats]{symnum}} for symbolic number coding of p-values. For
 #'  example, \code{symnum.args <- list(cutpoints = c(0, 0.0001, 0.001,
-#'  0.01, 0.05, 1), symbols = c("****", "***", "**", "*",  "ns"))}.
+#'  0.01, 0.05, Inf), symbols = c("****", "***", "**", "*",  "ns"))}.
 #'
 #'  In other words, we use the following convention for symbols indicating
 #'  statistical significance: \itemize{ \item \code{ns}: p > 0.05 \item
@@ -131,7 +131,7 @@ compare_means <- function(formula, data, method = "wilcox.test",
 
   # Keep only variables of interest
   data <- data %>%
-    dplyr::select_(.dots = c(group.by, group, variables))
+    df_select(vars = c(group.by, group, variables))
 
   # Case of formula with multiple variables
   #   1. Gather the data
@@ -199,7 +199,7 @@ compare_means <- function(formula, data, method = "wilcox.test",
         test.func, formula = formula,
         method = method, paired = paired, p.adjust.method = "none",...)
       ) %>%
-      dplyr::select_(.dots = c(group.by, "p")) %>%
+      df_select(vars = c(group.by, "p")) %>%
       unnest(cols = "p")
   }
 
@@ -208,7 +208,7 @@ compare_means <- function(formula, data, method = "wilcox.test",
   if(!c(".y." %in% colnames(res)))
     res <- res %>%
     dplyr::mutate(.y. = variables) %>%
-    dplyr::select_(.dots = c(group.by, ".y.", "dplyr::everything()"))
+    dplyr::select(!!!syms(c(group.by, ".y.")), dplyr::everything())
 
   # Select only reference groups if any
   #::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -242,7 +242,7 @@ compare_means <- function(formula, data, method = "wilcox.test",
 
   res %>%
     mutate(p.adj = signif(p.adj, digits = 2)) %>%
-    dplyr::tbl_df()
+    tibble::as_tibble()
 }
 
 
